Class: Aws::Route53GlobalResolver::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Route53GlobalResolver::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-route53globalresolver/client.rb,
sig/client.rbs
Overview
An API client for Route53GlobalResolver. To construct a client, you need to configure a :region and :credentials.
client = Aws::Route53GlobalResolver::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AssociateHostedZoneResponseSuccess, _BatchCreateFirewallRuleResponseSuccess, _BatchDeleteFirewallRuleResponseSuccess, _BatchUpdateFirewallRuleResponseSuccess, _CreateAccessSourceResponseSuccess, _CreateAccessTokenResponseSuccess, _CreateDNSViewResponseSuccess, _CreateFirewallDomainListResponseSuccess, _CreateFirewallRuleResponseSuccess, _CreateGlobalResolverResponseSuccess, _DeleteAccessSourceResponseSuccess, _DeleteAccessTokenResponseSuccess, _DeleteDNSViewResponseSuccess, _DeleteFirewallDomainListResponseSuccess, _DeleteFirewallRuleResponseSuccess, _DeleteGlobalResolverResponseSuccess, _DisableDNSViewResponseSuccess, _DisassociateHostedZoneResponseSuccess, _EnableDNSViewResponseSuccess, _GetAccessSourceResponseSuccess, _GetAccessTokenResponseSuccess, _GetDNSViewResponseSuccess, _GetFirewallDomainListResponseSuccess, _GetFirewallRuleResponseSuccess, _GetGlobalResolverResponseSuccess, _GetHostedZoneAssociationResponseSuccess, _GetManagedFirewallDomainListResponseSuccess, _ImportFirewallDomainsResponseSuccess, _ListAccessSourcesResponseSuccess, _ListAccessTokensResponseSuccess, _ListDNSViewsResponseSuccess, _ListFirewallDomainListsResponseSuccess, _ListFirewallDomainsResponseSuccess, _ListFirewallRulesResponseSuccess, _ListGlobalResolversResponseSuccess, _ListHostedZoneAssociationsResponseSuccess, _ListManagedFirewallDomainListsResponseSuccess, _ListSharedDNSViewsResponseSuccess, _ListTagsForResourceResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateAccessSourceResponseSuccess, _UpdateAccessTokenResponseSuccess, _UpdateDNSViewResponseSuccess, _UpdateFirewallDomainsResponseSuccess, _UpdateFirewallRuleResponseSuccess, _UpdateGlobalResolverResponseSuccess, _UpdateHostedZoneAssociationResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_hosted_zone(params = {}) ⇒ Types::AssociateHostedZoneOutput
Associates a Route 53 private hosted zone with a Route 53 Global Resolver resource.
-
#batch_create_firewall_rule(params = {}) ⇒ Types::BatchCreateFirewallRuleOutput
Creates multiple DNS firewall rules in a single operation.
-
#batch_delete_firewall_rule(params = {}) ⇒ Types::BatchDeleteFirewallRuleOutput
Deletes multiple DNS firewall rules in a single operation.
-
#batch_update_firewall_rule(params = {}) ⇒ Types::BatchUpdateFirewallRuleOutput
Updates multiple DNS firewall rules in a single operation.
-
#create_access_source(params = {}) ⇒ Types::CreateAccessSourceOutput
Creates an access source for a DNS view.
-
#create_access_token(params = {}) ⇒ Types::CreateAccessTokenOutput
Creates an access token for a DNS view.
-
#create_dns_view(params = {}) ⇒ Types::CreateDNSViewOutput
Creates a DNS view within a Route 53 Global Resolver.
-
#create_firewall_domain_list(params = {}) ⇒ Types::CreateFirewallDomainListOutput
Creates a firewall domain list.
-
#create_firewall_rule(params = {}) ⇒ Types::CreateFirewallRuleOutput
Creates a DNS firewall rule.
-
#create_global_resolver(params = {}) ⇒ Types::CreateGlobalResolverOutput
Creates a new Route 53 Global Resolver instance.
-
#delete_access_source(params = {}) ⇒ Types::DeleteAccessSourceOutput
Deletes an access source.
-
#delete_access_token(params = {}) ⇒ Types::DeleteAccessTokenOutput
Deletes an access token.
-
#delete_dns_view(params = {}) ⇒ Types::DeleteDNSViewOutput
Deletes a DNS view.
-
#delete_firewall_domain_list(params = {}) ⇒ Types::DeleteFirewallDomainListOutput
Deletes a firewall domain list.
-
#delete_firewall_rule(params = {}) ⇒ Types::DeleteFirewallRuleOutput
Deletes a DNS firewall rule.
-
#delete_global_resolver(params = {}) ⇒ Types::DeleteGlobalResolverOutput
Deletes a Route 53 Global Resolver instance.
-
#disable_dns_view(params = {}) ⇒ Types::DisableDNSViewOutput
Disables a DNS view, preventing it from serving DNS queries.
-
#disassociate_hosted_zone(params = {}) ⇒ Types::DisassociateHostedZoneOutput
Disassociates a Route 53 private hosted zone from a Route 53 Global Resolver resource.
-
#enable_dns_view(params = {}) ⇒ Types::EnableDNSViewOutput
Enables a disabled DNS view, allowing it to serve DNS queries again.
-
#get_access_source(params = {}) ⇒ Types::GetAccessSourceOutput
Retrieves information about an access source.
-
#get_access_token(params = {}) ⇒ Types::GetAccessTokenOutput
Retrieves information about an access token.
-
#get_dns_view(params = {}) ⇒ Types::GetDNSViewOutput
Retrieves information about a DNS view.
-
#get_firewall_domain_list(params = {}) ⇒ Types::GetFirewallDomainListOutput
Retrieves information about a firewall domain list.
-
#get_firewall_rule(params = {}) ⇒ Types::GetFirewallRuleOutput
Retrieves information about a DNS firewall rule.
-
#get_global_resolver(params = {}) ⇒ Types::GetGlobalResolverOutput
Retrieves information about a Route 53 Global Resolver instance.
-
#get_hosted_zone_association(params = {}) ⇒ Types::GetHostedZoneAssociationOutput
Retrieves information about a hosted zone association.
-
#get_managed_firewall_domain_list(params = {}) ⇒ Types::GetManagedFirewallDomainListOutput
Retrieves information about an Amazon Web Services-managed firewall domain list.
-
#import_firewall_domains(params = {}) ⇒ Types::ImportFirewallDomainsOutput
Imports a list of domains from an Amazon S3 file into a firewall domain list.
-
#list_access_sources(params = {}) ⇒ Types::ListAccessSourcesOutput
Lists all access sources with pagination support.
-
#list_access_tokens(params = {}) ⇒ Types::ListAccessTokensOutput
Lists all access tokens for a DNS view with pagination support.
-
#list_dns_views(params = {}) ⇒ Types::ListDNSViewsOutput
Lists all DNS views for a Route 53 Global Resolver with pagination support.
-
#list_firewall_domain_lists(params = {}) ⇒ Types::ListFirewallDomainListsOutput
Lists all firewall domain lists for a Route 53 Global Resolver with pagination support.
-
#list_firewall_domains(params = {}) ⇒ Types::ListFirewallDomainsOutput
Lists all the domains in DNS Firewall domain list you have created.
-
#list_firewall_rules(params = {}) ⇒ Types::ListFirewallRulesOutput
Lists all DNS firewall rules for a DNS view with pagination support.
-
#list_global_resolvers(params = {}) ⇒ Types::ListGlobalResolversOutput
Lists all Route 53 Global Resolver instances in your account with pagination support.
-
#list_hosted_zone_associations(params = {}) ⇒ Types::ListHostedZoneAssociationsOutput
Lists hosted zone associations with pagination support.
-
#list_managed_firewall_domain_lists(params = {}) ⇒ Types::ListManagedFirewallDomainListsOutput
Returns a paginated list of the Amazon Web Services Managed DNS Lists and the categories for DNS Firewall.
-
#list_shared_dns_views(params = {}) ⇒ Types::ListSharedDNSViewsOutput
Lists the DNS views that have been shared with your Amazon Web Services account through Amazon Web Services Resource Access Manager (Amazon Web Services RAM), with pagination support.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags associated with a Route 53 Global Resolver resource.
-
#tag_resource(params = {}) ⇒ Struct
Adds or updates tags for a Route 53 Global Resolver resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from a Route 53 Global Resolver resource.
-
#update_access_source(params = {}) ⇒ Types::UpdateAccessSourceOutput
Updates the configuration of an access source.
-
#update_access_token(params = {}) ⇒ Types::UpdateAccessTokenOutput
Updates the configuration of an access token.
-
#update_dns_view(params = {}) ⇒ Types::UpdateDNSViewOutput
Updates the configuration of a DNS view.
-
#update_firewall_domains(params = {}) ⇒ Types::UpdateFirewallDomainsOutput
Updates a DNS Firewall domain list from an array of specified domains.
-
#update_firewall_rule(params = {}) ⇒ Types::UpdateFirewallRuleOutput
Updates the configuration of a DNS firewall rule.
-
#update_global_resolver(params = {}) ⇒ Types::UpdateGlobalResolverOutput
Updates the configuration of a Route 53 Global Resolver instance.
-
#update_hosted_zone_association(params = {}) ⇒ Types::UpdateHostedZoneAssociationOutput
Updates the configuration of a hosted zone association.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-route53globalresolver/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3601 3602 3603 |
# File 'lib/aws-sdk-route53globalresolver/client.rb', line 3601 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3604 3605 3606 |
# File 'lib/aws-sdk-route53globalresolver/client.rb', line 3604 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#associate_hosted_zone(params = {}) ⇒ Types::AssociateHostedZoneOutput
Associates a Route 53 private hosted zone with a Route 53 Global Resolver resource. This allows the resolver to resolve DNS queries for the private hosted zone from anywhere globally.
Route 53 Global Resolver is a global service that supports resolvers
in multiple Amazon Web Services Regions but you must specify the US
East (Ohio) Region to create, update, or otherwise work with Route 53
Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.
93 |
# File 'sig/client.rbs', line 93
def associate_hosted_zone: (
|
#batch_create_firewall_rule(params = {}) ⇒ Types::BatchCreateFirewallRuleOutput
Creates multiple DNS firewall rules in a single operation. This is more efficient than creating rules individually when you need to set up multiple rules at once.
Route 53 Global Resolver is a global service that supports resolvers
in multiple Amazon Web Services Regions but you must specify the US
East (Ohio) Region to create, update, or otherwise work with Route 53
Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.
106 |
# File 'sig/client.rbs', line 106
def batch_create_firewall_rule: (
|
#batch_delete_firewall_rule(params = {}) ⇒ Types::BatchDeleteFirewallRuleOutput
Deletes multiple DNS firewall rules in a single operation. This is more efficient than deleting rules individually.
Route 53 Global Resolver is a global service that supports resolvers
in multiple Amazon Web Services Regions but you must specify the US
East (Ohio) Region to create, update, or otherwise work with Route 53
Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.
134 |
# File 'sig/client.rbs', line 134
def batch_delete_firewall_rule: (
|
#batch_update_firewall_rule(params = {}) ⇒ Types::BatchUpdateFirewallRuleOutput
Updates multiple DNS firewall rules in a single operation. This is more efficient than updating rules individually.
Route 53 Global Resolver is a global service that supports resolvers
in multiple Amazon Web Services Regions but you must specify the US
East (Ohio) Region to create, update, or otherwise work with Route 53
Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.
149 |
# File 'sig/client.rbs', line 149
def batch_update_firewall_rule: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3574 3575 3576 3577 3578 3579 3580 3581 3582 3583 3584 3585 3586 3587 3588 3589 3590 |
# File 'lib/aws-sdk-route53globalresolver/client.rb', line 3574 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Route53GlobalResolver') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-route53globalresolver' context[:gem_version] = '1.11.0' Seahorse::Client::Request.new(handlers, context) end |
#create_access_source(params = {}) ⇒ Types::CreateAccessSourceOutput
Creates an access source for a DNS view. Access sources define IP addresses or CIDR ranges that are allowed to send DNS queries to the Route 53 Global Resolver, along with the permitted DNS protocols.
Route 53 Global Resolver is a global service that supports resolvers
in multiple Amazon Web Services Regions but you must specify the US
East (Ohio) Region to create, update, or otherwise work with Route 53
Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.
182 |
# File 'sig/client.rbs', line 182
def create_access_source: (
|
#create_access_token(params = {}) ⇒ Types::CreateAccessTokenOutput
Creates an access token for a DNS view. Access tokens provide token-based authentication for DNS-over-HTTPS (DoH) and DNS-over-TLS (DoT) connections to the Route 53 Global Resolver.
Route 53 Global Resolver is a global service that supports resolvers
in multiple Amazon Web Services Regions but you must specify the US
East (Ohio) Region to create, update, or otherwise work with Route 53
Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.
206 |
# File 'sig/client.rbs', line 206
def create_access_token: (
|
#create_dns_view(params = {}) ⇒ Types::CreateDNSViewOutput
Creates a DNS view within a Route 53 Global Resolver. A DNS view models end users, user groups, networks, and devices, and serves as a parent resource that holds configurations controlling access, authorization, DNS firewall rules, and forwarding rules.
Route 53 Global Resolver is a global service that supports resolvers
in multiple Amazon Web Services Regions but you must specify the US
East (Ohio) Region to create, update, or otherwise work with Route 53
Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.
231 |
# File 'sig/client.rbs', line 231
def create_dns_view: (
|
#create_firewall_domain_list(params = {}) ⇒ Types::CreateFirewallDomainListOutput
Creates a firewall domain list. Domain lists are reusable sets of domain specifications that you use in DNS firewall rules to allow, block, or alert on DNS queries to specific domains.
Route 53 Global Resolver is a global service that supports resolvers
in multiple Amazon Web Services Regions but you must specify the US
East (Ohio) Region to create, update, or otherwise work with Route 53
Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.
256 |
# File 'sig/client.rbs', line 256
def create_firewall_domain_list: (
|
#create_firewall_rule(params = {}) ⇒ Types::CreateFirewallRuleOutput
Creates a DNS firewall rule. Firewall rules define actions (ALLOW, BLOCK, or ALERT) to take on DNS queries that match specified domain lists, managed domain lists, or advanced threat protections.
Route 53 Global Resolver is a global service that supports resolvers
in multiple Amazon Web Services Regions but you must specify the US
East (Ohio) Region to create, update, or otherwise work with Route 53
Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.
286 |
# File 'sig/client.rbs', line 286
def create_firewall_rule: (
|
#create_global_resolver(params = {}) ⇒ Types::CreateGlobalResolverOutput
Creates a new Route 53 Global Resolver instance. A Route 53 Global Resolver is a global, internet-accessible DNS resolver that provides secure DNS resolution for both public and private domains through global anycast IP addresses.
Route 53 Global Resolver is a global service that supports resolvers
in multiple Amazon Web Services Regions but you must specify the US
East (Ohio) Region to create, update, or otherwise work with Route 53
Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.
322 |
# File 'sig/client.rbs', line 322
def create_global_resolver: (
|
#delete_access_source(params = {}) ⇒ Types::DeleteAccessSourceOutput
Deletes an access source. This operation cannot be undone.
Route 53 Global Resolver is a global service that supports resolvers
in multiple Amazon Web Services Regions but you must specify the US
East (Ohio) Region to create, update, or otherwise work with Route 53
Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.
347 |
# File 'sig/client.rbs', line 347
def delete_access_source: (
|
#delete_access_token(params = {}) ⇒ Types::DeleteAccessTokenOutput
Deletes an access token. This operation cannot be undone.
Route 53 Global Resolver is a global service that supports resolvers
in multiple Amazon Web Services Regions but you must specify the US
East (Ohio) Region to create, update, or otherwise work with Route 53
Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.
359 |
# File 'sig/client.rbs', line 359
def delete_access_token: (
|
#delete_dns_view(params = {}) ⇒ Types::DeleteDNSViewOutput
Deletes a DNS view. This operation cannot be undone.
Route 53 Global Resolver is a global service that supports resolvers
in multiple Amazon Web Services Regions but you must specify the US
East (Ohio) Region to create, update, or otherwise work with Route 53
Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.
380 |
# File 'sig/client.rbs', line 380
def delete_dns_view: (
|
#delete_firewall_domain_list(params = {}) ⇒ Types::DeleteFirewallDomainListOutput
Deletes a firewall domain list. This operation cannot be undone.
Route 53 Global Resolver is a global service that supports resolvers
in multiple Amazon Web Services Regions but you must specify the US
East (Ohio) Region to create, update, or otherwise work with Route 53
Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.
393 |
# File 'sig/client.rbs', line 393
def delete_firewall_domain_list: (
|
#delete_firewall_rule(params = {}) ⇒ Types::DeleteFirewallRuleOutput
Deletes a DNS firewall rule. This operation cannot be undone.
Route 53 Global Resolver is a global service that supports resolvers
in multiple Amazon Web Services Regions but you must specify the US
East (Ohio) Region to create, update, or otherwise work with Route 53
Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.
419 |
# File 'sig/client.rbs', line 419
def delete_firewall_rule: (
|
#delete_global_resolver(params = {}) ⇒ Types::DeleteGlobalResolverOutput
Deletes a Route 53 Global Resolver instance. This operation cannot be undone. All associated DNS views, access sources, tokens, and firewall rules are also deleted.
Route 53 Global Resolver is a global service that supports resolvers
in multiple Amazon Web Services Regions but you must specify the US
East (Ohio) Region to create, update, or otherwise work with Route 53
Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.
442 |
# File 'sig/client.rbs', line 442
def delete_global_resolver: (
|
#disable_dns_view(params = {}) ⇒ Types::DisableDNSViewOutput
Disables a DNS view, preventing it from serving DNS queries.
Route 53 Global Resolver is a global service that supports resolvers
in multiple Amazon Web Services Regions but you must specify the US
East (Ohio) Region to create, update, or otherwise work with Route 53
Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.
463 |
# File 'sig/client.rbs', line 463
def disable_dns_view: (
|
#disassociate_hosted_zone(params = {}) ⇒ Types::DisassociateHostedZoneOutput
Disassociates a Route 53 private hosted zone from a Route 53 Global Resolver resource.
Route 53 Global Resolver is a global service that supports resolvers
in multiple Amazon Web Services Regions but you must specify the US
East (Ohio) Region to create, update, or otherwise work with Route 53
Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.
480 |
# File 'sig/client.rbs', line 480
def disassociate_hosted_zone: (
|
#enable_dns_view(params = {}) ⇒ Types::EnableDNSViewOutput
Enables a disabled DNS view, allowing it to serve DNS queries again.
Route 53 Global Resolver is a global service that supports resolvers
in multiple Amazon Web Services Regions but you must specify the US
East (Ohio) Region to create, update, or otherwise work with Route 53
Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.
502 |
# File 'sig/client.rbs', line 502
def enable_dns_view: (
|
#get_access_source(params = {}) ⇒ Types::GetAccessSourceOutput
Retrieves information about an access source.
Route 53 Global Resolver is a global service that supports resolvers
in multiple Amazon Web Services Regions but you must specify the US
East (Ohio) Region to create, update, or otherwise work with Route 53
Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.
521 |
# File 'sig/client.rbs', line 521
def get_access_source: (
|
#get_access_token(params = {}) ⇒ Types::GetAccessTokenOutput
Retrieves information about an access token.
Route 53 Global Resolver is a global service that supports resolvers
in multiple Amazon Web Services Regions but you must specify the US
East (Ohio) Region to create, update, or otherwise work with Route 53
Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.
541 |
# File 'sig/client.rbs', line 541
def get_access_token: (
|
#get_dns_view(params = {}) ⇒ Types::GetDNSViewOutput
Retrieves information about a DNS view.
Route 53 Global Resolver is a global service that supports resolvers
in multiple Amazon Web Services Regions but you must specify the US
East (Ohio) Region to create, update, or otherwise work with Route 53
Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.
562 |
# File 'sig/client.rbs', line 562
def get_dns_view: (
|
#get_firewall_domain_list(params = {}) ⇒ Types::GetFirewallDomainListOutput
Retrieves information about a firewall domain list.
Route 53 Global Resolver is a global service that supports resolvers
in multiple Amazon Web Services Regions but you must specify the US
East (Ohio) Region to create, update, or otherwise work with Route 53
Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.
582 |
# File 'sig/client.rbs', line 582
def get_firewall_domain_list: (
|
#get_firewall_rule(params = {}) ⇒ Types::GetFirewallRuleOutput
Retrieves information about a DNS firewall rule.
Route 53 Global Resolver is a global service that supports resolvers
in multiple Amazon Web Services Regions but you must specify the US
East (Ohio) Region to create, update, or otherwise work with Route 53
Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.
608 |
# File 'sig/client.rbs', line 608
def get_firewall_rule: (
|
#get_global_resolver(params = {}) ⇒ Types::GetGlobalResolverOutput
Retrieves information about a Route 53 Global Resolver instance.
Route 53 Global Resolver is a global service that supports resolvers
in multiple Amazon Web Services Regions but you must specify the US
East (Ohio) Region to create, update, or otherwise work with Route 53
Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.
631 |
# File 'sig/client.rbs', line 631
def get_global_resolver: (
|
#get_hosted_zone_association(params = {}) ⇒ Types::GetHostedZoneAssociationOutput
Retrieves information about a hosted zone association.
Route 53 Global Resolver is a global service that supports resolvers
in multiple Amazon Web Services Regions but you must specify the US
East (Ohio) Region to create, update, or otherwise work with Route 53
Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.
648 |
# File 'sig/client.rbs', line 648
def get_hosted_zone_association: (
|
#get_managed_firewall_domain_list(params = {}) ⇒ Types::GetManagedFirewallDomainListOutput
Retrieves information about an Amazon Web Services-managed firewall domain list. Managed domain lists contain domains associated with malicious activity, content categories, or specific threats.
Route 53 Global Resolver is a global service that supports resolvers
in multiple Amazon Web Services Regions but you must specify the US
East (Ohio) Region to create, update, or otherwise work with Route 53
Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.
661 |
# File 'sig/client.rbs', line 661
def get_managed_firewall_domain_list: (
|
#import_firewall_domains(params = {}) ⇒ Types::ImportFirewallDomainsOutput
Imports a list of domains from an Amazon S3 file into a firewall domain list. The file should contain one domain per line.
Route 53 Global Resolver is a global service that supports resolvers
in multiple Amazon Web Services Regions but you must specify the US
East (Ohio) Region to create, update, or otherwise work with Route 53
Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.
673 |
# File 'sig/client.rbs', line 673
def import_firewall_domains: (
|
#list_access_sources(params = {}) ⇒ Types::ListAccessSourcesOutput
Lists all access sources with pagination support.
Route 53 Global Resolver is a global service that supports resolvers
in multiple Amazon Web Services Regions but you must specify the US
East (Ohio) Region to create, update, or otherwise work with Route 53
Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
686 |
# File 'sig/client.rbs', line 686
def list_access_sources: (
|
#list_access_tokens(params = {}) ⇒ Types::ListAccessTokensOutput
Lists all access tokens for a DNS view with pagination support.
Route 53 Global Resolver is a global service that supports resolvers
in multiple Amazon Web Services Regions but you must specify the US
East (Ohio) Region to create, update, or otherwise work with Route 53
Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
699 |
# File 'sig/client.rbs', line 699
def list_access_tokens: (
|
#list_dns_views(params = {}) ⇒ Types::ListDNSViewsOutput
Lists all DNS views for a Route 53 Global Resolver with pagination support.
Route 53 Global Resolver is a global service that supports resolvers
in multiple Amazon Web Services Regions but you must specify the US
East (Ohio) Region to create, update, or otherwise work with Route 53
Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
713 |
# File 'sig/client.rbs', line 713
def list_dns_views: (
|
#list_firewall_domain_lists(params = {}) ⇒ Types::ListFirewallDomainListsOutput
Lists all firewall domain lists for a Route 53 Global Resolver with pagination support.
Route 53 Global Resolver is a global service that supports resolvers
in multiple Amazon Web Services Regions but you must specify the US
East (Ohio) Region to create, update, or otherwise work with Route 53
Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
726 |
# File 'sig/client.rbs', line 726
def list_firewall_domain_lists: (
|
#list_firewall_domains(params = {}) ⇒ Types::ListFirewallDomainsOutput
Lists all the domains in DNS Firewall domain list you have created.
Route 53 Global Resolver is a global service that supports resolvers
in multiple Amazon Web Services Regions but you must specify the US
East (Ohio) Region to create, update, or otherwise work with Route 53
Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
739 |
# File 'sig/client.rbs', line 739
def list_firewall_domains: (
|
#list_firewall_rules(params = {}) ⇒ Types::ListFirewallRulesOutput
Lists all DNS firewall rules for a DNS view with pagination support.
Route 53 Global Resolver is a global service that supports resolvers
in multiple Amazon Web Services Regions but you must specify the US
East (Ohio) Region to create, update, or otherwise work with Route 53
Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
752 |
# File 'sig/client.rbs', line 752
def list_firewall_rules: (
|
#list_global_resolvers(params = {}) ⇒ Types::ListGlobalResolversOutput
Lists all Route 53 Global Resolver instances in your account with pagination support.
Route 53 Global Resolver is a global service that supports resolvers
in multiple Amazon Web Services Regions but you must specify the US
East (Ohio) Region to create, update, or otherwise work with Route 53
Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
766 |
# File 'sig/client.rbs', line 766
def list_global_resolvers: (
|
#list_hosted_zone_associations(params = {}) ⇒ Types::ListHostedZoneAssociationsOutput
Lists hosted zone associations with pagination support. Specify a DNS
view through the resourceArn parameter to list the hosted zone
associations for that DNS view, or omit it to list all hosted zone
associations in your Amazon Web Services account.
Route 53 Global Resolver is a global service that supports resolvers
in multiple Amazon Web Services Regions but you must specify the US
East (Ohio) Region to create, update, or otherwise work with Route 53
Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
778 |
# File 'sig/client.rbs', line 778
def list_hosted_zone_associations: (
|
#list_managed_firewall_domain_lists(params = {}) ⇒ Types::ListManagedFirewallDomainListsOutput
Returns a paginated list of the Amazon Web Services Managed DNS Lists
and the categories for DNS Firewall. The categories are either
THREAT or CONTENT.
Route 53 Global Resolver is a global service that supports resolvers
in multiple Amazon Web Services Regions but you must specify the US
East (Ohio) Region to create, update, or otherwise work with Route 53
Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
791 |
# File 'sig/client.rbs', line 791
def list_managed_firewall_domain_lists: (
|
#list_shared_dns_views(params = {}) ⇒ Types::ListSharedDNSViewsOutput
Lists the DNS views that have been shared with your Amazon Web Services account through Amazon Web Services Resource Access Manager (Amazon Web Services RAM), with pagination support.
Route 53 Global Resolver is a global service that supports resolvers
in multiple Amazon Web Services Regions but you must specify the US
East (Ohio) Region to create, update, or otherwise work with Route 53
Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
804 |
# File 'sig/client.rbs', line 804
def list_shared_dns_views: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags associated with a Route 53 Global Resolver resource.
Route 53 Global Resolver is a global service that supports resolvers
in multiple Amazon Web Services Regions but you must specify the US
East (Ohio) Region to create, update, or otherwise work with Route 53
Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.
815 |
# File 'sig/client.rbs', line 815
def list_tags_for_resource: (
|
#tag_resource(params = {}) ⇒ Struct
Adds or updates tags for a Route 53 Global Resolver resource. Tags are key-value pairs that help you organize and identify your resources.
Route 53 Global Resolver is a global service that supports resolvers
in multiple Amazon Web Services Regions but you must specify the US
East (Ohio) Region to create, update, or otherwise work with Route 53
Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.
824 |
# File 'sig/client.rbs', line 824
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes tags from a Route 53 Global Resolver resource.
Route 53 Global Resolver is a global service that supports resolvers
in multiple Amazon Web Services Regions but you must specify the US
East (Ohio) Region to create, update, or otherwise work with Route 53
Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.
834 |
# File 'sig/client.rbs', line 834
def untag_resource: (
|
#update_access_source(params = {}) ⇒ Types::UpdateAccessSourceOutput
Updates the configuration of an access source.
Route 53 Global Resolver is a global service that supports resolvers
in multiple Amazon Web Services Regions but you must specify the US
East (Ohio) Region to create, update, or otherwise work with Route 53
Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.
854 |
# File 'sig/client.rbs', line 854
def update_access_source: (
|
#update_access_token(params = {}) ⇒ Types::UpdateAccessTokenOutput
Updates the configuration of an access token.
Route 53 Global Resolver is a global service that supports resolvers
in multiple Amazon Web Services Regions but you must specify the US
East (Ohio) Region to create, update, or otherwise work with Route 53
Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.
869 |
# File 'sig/client.rbs', line 869
def update_access_token: (
|
#update_dns_view(params = {}) ⇒ Types::UpdateDNSViewOutput
Updates the configuration of a DNS view.
Route 53 Global Resolver is a global service that supports resolvers
in multiple Amazon Web Services Regions but you must specify the US
East (Ohio) Region to create, update, or otherwise work with Route 53
Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.
891 |
# File 'sig/client.rbs', line 891
def update_dns_view: (
|
#update_firewall_domains(params = {}) ⇒ Types::UpdateFirewallDomainsOutput
Updates a DNS Firewall domain list from an array of specified domains.
Route 53 Global Resolver is a global service that supports resolvers
in multiple Amazon Web Services Regions but you must specify the US
East (Ohio) Region to create, update, or otherwise work with Route 53
Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.
908 |
# File 'sig/client.rbs', line 908
def update_firewall_domains: (
|
#update_firewall_rule(params = {}) ⇒ Types::UpdateFirewallRuleOutput
Updates the configuration of a DNS firewall rule.
Route 53 Global Resolver is a global service that supports resolvers
in multiple Amazon Web Services Regions but you must specify the US
East (Ohio) Region to create, update, or otherwise work with Route 53
Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.
936 |
# File 'sig/client.rbs', line 936
def update_firewall_rule: (
|
#update_global_resolver(params = {}) ⇒ Types::UpdateGlobalResolverOutput
Updates the configuration of a Route 53 Global Resolver instance. You can modify the name, description, and observability Region.
Route 53 Global Resolver is a global service that supports resolvers
in multiple Amazon Web Services Regions but you must specify the US
East (Ohio) Region to create, update, or otherwise work with Route 53
Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.
970 |
# File 'sig/client.rbs', line 970
def update_global_resolver: (
|
#update_hosted_zone_association(params = {}) ⇒ Types::UpdateHostedZoneAssociationOutput
Updates the configuration of a hosted zone association.
Route 53 Global Resolver is a global service that supports resolvers
in multiple Amazon Web Services Regions but you must specify the US
East (Ohio) Region to create, update, or otherwise work with Route 53
Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.
992 |
# File 'sig/client.rbs', line 992
def update_hosted_zone_association: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3594 3595 3596 |
# File 'lib/aws-sdk-route53globalresolver/client.rb', line 3594 def waiter_names [] end |