Class: Aws::Route53GlobalResolver::Types::ImportFirewallDomainsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53GlobalResolver::Types::ImportFirewallDomainsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53globalresolver/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_file_url ⇒ String
The fully qualified URL of the file in Amazon S3 that contains the list of domains to import.
-
#firewall_domain_list_id ⇒ String
ID of the DNS Firewall domain list that you want to import the domain list to.
-
#operation ⇒ String
This value is ‘REPLACE`, and it updates the domain list to match the list of domains in the imported file.
Instance Attribute Details
#domain_file_url ⇒ String
The fully qualified URL of the file in Amazon S3 that contains the list of domains to import. The file should contain one domain per line.
3267 3268 3269 3270 3271 3272 3273 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 3267 class ImportFirewallDomainsInput < Struct.new( :domain_file_url, :firewall_domain_list_id, :operation) SENSITIVE = [] include Aws::Structure end |
#firewall_domain_list_id ⇒ String
ID of the DNS Firewall domain list that you want to import the domain list to.
3267 3268 3269 3270 3271 3272 3273 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 3267 class ImportFirewallDomainsInput < Struct.new( :domain_file_url, :firewall_domain_list_id, :operation) SENSITIVE = [] include Aws::Structure end |
#operation ⇒ String
This value is ‘REPLACE`, and it updates the domain list to match the list of domains in the imported file.
3267 3268 3269 3270 3271 3272 3273 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 3267 class ImportFirewallDomainsInput < Struct.new( :domain_file_url, :firewall_domain_list_id, :operation) SENSITIVE = [] include Aws::Structure end |