Class: Aws::Route53GlobalResolver::Types::ImportFirewallDomainsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53GlobalResolver::Types::ImportFirewallDomainsOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53globalresolver/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#id ⇒ String
ID of the DNS Firewall domain list that you imported the domain list to.
-
#name ⇒ String
Name of the DNS Firewall domain list.
-
#status ⇒ String
Operational status of the DNS Firewall domain list.
Instance Attribute Details
#id ⇒ String
ID of the DNS Firewall domain list that you imported the domain list to.
3290 3291 3292 3293 3294 3295 3296 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 3290 class ImportFirewallDomainsOutput < Struct.new( :id, :name, :status) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Name of the DNS Firewall domain list.
3290 3291 3292 3293 3294 3295 3296 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 3290 class ImportFirewallDomainsOutput < Struct.new( :id, :name, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Operational status of the DNS Firewall domain list.
3290 3291 3292 3293 3294 3295 3296 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 3290 class ImportFirewallDomainsOutput < Struct.new( :id, :name, :status) SENSITIVE = [] include Aws::Structure end |