Class: Aws::Route53GlobalResolver::Types::SharedDNSViewSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53GlobalResolver::Types::SharedDNSViewSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53globalresolver/types.rb
Overview
Summary information about a DNS view that has been shared with your Amazon Web Services account through Amazon Web Services RAM.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the DNS view.
-
#client_token ⇒ String
The unique string that identifies the request and ensures idempotency.
-
#created_at ⇒ Time
The date and time when the DNS view was created.
-
#description ⇒ String
A description of the DNS view.
-
#dnssec_validation ⇒ String
Whether DNSSEC validation is enabled for the DNS view.
-
#edns_client_subnet ⇒ String
Whether EDNS Client Subnet injection is enabled for the DNS view.
-
#firewall_rules_fail_open ⇒ String
Whether firewall rules fail open when they cannot be evaluated.
-
#global_resolver_id ⇒ String
The ID of the global resolver that the DNS view is associated with.
-
#id ⇒ String
The unique identifier of the DNS view.
-
#name ⇒ String
The name of the DNS view.
-
#owner_account_id ⇒ String
The ID of the Amazon Web Services account that owns the DNS view and shared it with your Amazon Web Services account.
-
#status ⇒ String
The current status of the DNS view.
-
#updated_at ⇒ Time
The date and time when the DNS view was last updated.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the DNS view.
3917 3918 3919 3920 3921 3922 3923 3924 3925 3926 3927 3928 3929 3930 3931 3932 3933 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 3917 class SharedDNSViewSummary < Struct.new( :id, :arn, :client_token, :dnssec_validation, :edns_client_subnet, :firewall_rules_fail_open, :name, :description, :global_resolver_id, :created_at, :updated_at, :status, :owner_account_id) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
The unique string that identifies the request and ensures idempotency.
3917 3918 3919 3920 3921 3922 3923 3924 3925 3926 3927 3928 3929 3930 3931 3932 3933 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 3917 class SharedDNSViewSummary < Struct.new( :id, :arn, :client_token, :dnssec_validation, :edns_client_subnet, :firewall_rules_fail_open, :name, :description, :global_resolver_id, :created_at, :updated_at, :status, :owner_account_id) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time when the DNS view was created.
3917 3918 3919 3920 3921 3922 3923 3924 3925 3926 3927 3928 3929 3930 3931 3932 3933 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 3917 class SharedDNSViewSummary < Struct.new( :id, :arn, :client_token, :dnssec_validation, :edns_client_subnet, :firewall_rules_fail_open, :name, :description, :global_resolver_id, :created_at, :updated_at, :status, :owner_account_id) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the DNS view.
3917 3918 3919 3920 3921 3922 3923 3924 3925 3926 3927 3928 3929 3930 3931 3932 3933 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 3917 class SharedDNSViewSummary < Struct.new( :id, :arn, :client_token, :dnssec_validation, :edns_client_subnet, :firewall_rules_fail_open, :name, :description, :global_resolver_id, :created_at, :updated_at, :status, :owner_account_id) SENSITIVE = [] include Aws::Structure end |
#dnssec_validation ⇒ String
Whether DNSSEC validation is enabled for the DNS view.
3917 3918 3919 3920 3921 3922 3923 3924 3925 3926 3927 3928 3929 3930 3931 3932 3933 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 3917 class SharedDNSViewSummary < Struct.new( :id, :arn, :client_token, :dnssec_validation, :edns_client_subnet, :firewall_rules_fail_open, :name, :description, :global_resolver_id, :created_at, :updated_at, :status, :owner_account_id) SENSITIVE = [] include Aws::Structure end |
#edns_client_subnet ⇒ String
Whether EDNS Client Subnet injection is enabled for the DNS view.
3917 3918 3919 3920 3921 3922 3923 3924 3925 3926 3927 3928 3929 3930 3931 3932 3933 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 3917 class SharedDNSViewSummary < Struct.new( :id, :arn, :client_token, :dnssec_validation, :edns_client_subnet, :firewall_rules_fail_open, :name, :description, :global_resolver_id, :created_at, :updated_at, :status, :owner_account_id) SENSITIVE = [] include Aws::Structure end |
#firewall_rules_fail_open ⇒ String
Whether firewall rules fail open when they cannot be evaluated.
3917 3918 3919 3920 3921 3922 3923 3924 3925 3926 3927 3928 3929 3930 3931 3932 3933 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 3917 class SharedDNSViewSummary < Struct.new( :id, :arn, :client_token, :dnssec_validation, :edns_client_subnet, :firewall_rules_fail_open, :name, :description, :global_resolver_id, :created_at, :updated_at, :status, :owner_account_id) SENSITIVE = [] include Aws::Structure end |
#global_resolver_id ⇒ String
The ID of the global resolver that the DNS view is associated with.
3917 3918 3919 3920 3921 3922 3923 3924 3925 3926 3927 3928 3929 3930 3931 3932 3933 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 3917 class SharedDNSViewSummary < Struct.new( :id, :arn, :client_token, :dnssec_validation, :edns_client_subnet, :firewall_rules_fail_open, :name, :description, :global_resolver_id, :created_at, :updated_at, :status, :owner_account_id) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique identifier of the DNS view.
3917 3918 3919 3920 3921 3922 3923 3924 3925 3926 3927 3928 3929 3930 3931 3932 3933 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 3917 class SharedDNSViewSummary < Struct.new( :id, :arn, :client_token, :dnssec_validation, :edns_client_subnet, :firewall_rules_fail_open, :name, :description, :global_resolver_id, :created_at, :updated_at, :status, :owner_account_id) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the DNS view.
3917 3918 3919 3920 3921 3922 3923 3924 3925 3926 3927 3928 3929 3930 3931 3932 3933 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 3917 class SharedDNSViewSummary < Struct.new( :id, :arn, :client_token, :dnssec_validation, :edns_client_subnet, :firewall_rules_fail_open, :name, :description, :global_resolver_id, :created_at, :updated_at, :status, :owner_account_id) SENSITIVE = [] include Aws::Structure end |
#owner_account_id ⇒ String
The ID of the Amazon Web Services account that owns the DNS view and shared it with your Amazon Web Services account.
3917 3918 3919 3920 3921 3922 3923 3924 3925 3926 3927 3928 3929 3930 3931 3932 3933 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 3917 class SharedDNSViewSummary < Struct.new( :id, :arn, :client_token, :dnssec_validation, :edns_client_subnet, :firewall_rules_fail_open, :name, :description, :global_resolver_id, :created_at, :updated_at, :status, :owner_account_id) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the DNS view.
3917 3918 3919 3920 3921 3922 3923 3924 3925 3926 3927 3928 3929 3930 3931 3932 3933 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 3917 class SharedDNSViewSummary < Struct.new( :id, :arn, :client_token, :dnssec_validation, :edns_client_subnet, :firewall_rules_fail_open, :name, :description, :global_resolver_id, :created_at, :updated_at, :status, :owner_account_id) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time when the DNS view was last updated.
3917 3918 3919 3920 3921 3922 3923 3924 3925 3926 3927 3928 3929 3930 3931 3932 3933 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 3917 class SharedDNSViewSummary < Struct.new( :id, :arn, :client_token, :dnssec_validation, :edns_client_subnet, :firewall_rules_fail_open, :name, :description, :global_resolver_id, :created_at, :updated_at, :status, :owner_account_id) SENSITIVE = [] include Aws::Structure end |