Class: Aws::Route53GlobalResolver::Types::ThrottlingException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-route53globalresolver/types.rb

Overview

The request was throttled due to too many requests. Wait a moment and try again.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


3978
3979
3980
3981
3982
3983
3984
3985
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 3978

class ThrottlingException < Struct.new(
  :message,
  :service_code,
  :quota_code,
  :retry_after_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#quota_codeString

The quota code recognized by the Amazon Web Services Service Quotas service.

Returns:

  • (String)


3978
3979
3980
3981
3982
3983
3984
3985
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 3978

class ThrottlingException < Struct.new(
  :message,
  :service_code,
  :quota_code,
  :retry_after_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#retry_after_secondsInteger

Number of seconds in which the caller can retry the request.

Returns:

  • (Integer)


3978
3979
3980
3981
3982
3983
3984
3985
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 3978

class ThrottlingException < Struct.new(
  :message,
  :service_code,
  :quota_code,
  :retry_after_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#service_codeString

The code for the Amazon Web Services service that owns the quota.

Returns:

  • (String)


3978
3979
3980
3981
3982
3983
3984
3985
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 3978

class ThrottlingException < Struct.new(
  :message,
  :service_code,
  :quota_code,
  :retry_after_seconds)
  SENSITIVE = []
  include Aws::Structure
end