Class: Aws::Route53GlobalResolver::Types::UpdateAccessSourceOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-route53globalresolver/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the updated access source.

Returns:

  • (String)


4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4082

class UpdateAccessSourceOutput < Struct.new(
  :arn,
  :cidr,
  :created_at,
  :id,
  :ip_address_type,
  :name,
  :dns_view_id,
  :protocol,
  :status,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#cidrString

The CIDR block of the updated access source.

Returns:

  • (String)


4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4082

class UpdateAccessSourceOutput < Struct.new(
  :arn,
  :cidr,
  :created_at,
  :id,
  :ip_address_type,
  :name,
  :dns_view_id,
  :protocol,
  :status,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time when the access source was originally created.

Returns:

  • (Time)


4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4082

class UpdateAccessSourceOutput < Struct.new(
  :arn,
  :cidr,
  :created_at,
  :id,
  :ip_address_type,
  :name,
  :dns_view_id,
  :protocol,
  :status,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#dns_view_idString

The ID of the DNS view associated with the updated access source.

Returns:

  • (String)


4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4082

class UpdateAccessSourceOutput < Struct.new(
  :arn,
  :cidr,
  :created_at,
  :id,
  :ip_address_type,
  :name,
  :dns_view_id,
  :protocol,
  :status,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The unique identifier of the updated access source.

Returns:

  • (String)


4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4082

class UpdateAccessSourceOutput < Struct.new(
  :arn,
  :cidr,
  :created_at,
  :id,
  :ip_address_type,
  :name,
  :dns_view_id,
  :protocol,
  :status,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#ip_address_typeString

The IP address type of the updated access source.

Returns:

  • (String)


4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4082

class UpdateAccessSourceOutput < Struct.new(
  :arn,
  :cidr,
  :created_at,
  :id,
  :ip_address_type,
  :name,
  :dns_view_id,
  :protocol,
  :status,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the updated access source.

Returns:

  • (String)


4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4082

class UpdateAccessSourceOutput < Struct.new(
  :arn,
  :cidr,
  :created_at,
  :id,
  :ip_address_type,
  :name,
  :dns_view_id,
  :protocol,
  :status,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#protocolString

The protocol of the updated access source.

Returns:

  • (String)


4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4082

class UpdateAccessSourceOutput < Struct.new(
  :arn,
  :cidr,
  :created_at,
  :id,
  :ip_address_type,
  :name,
  :dns_view_id,
  :protocol,
  :status,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the updated access source.

Returns:

  • (String)


4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4082

class UpdateAccessSourceOutput < Struct.new(
  :arn,
  :cidr,
  :created_at,
  :id,
  :ip_address_type,
  :name,
  :dns_view_id,
  :protocol,
  :status,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The date and time when the access source was last updated.

Returns:

  • (Time)


4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4082

class UpdateAccessSourceOutput < Struct.new(
  :arn,
  :cidr,
  :created_at,
  :id,
  :ip_address_type,
  :name,
  :dns_view_id,
  :protocol,
  :status,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end