Class: Aws::Route53GlobalResolver::Types::UpdateDNSViewOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-route53globalresolver/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the updated DNS view.

Returns:

  • (String)


4222
4223
4224
4225
4226
4227
4228
4229
4230
4231
4232
4233
4234
4235
4236
4237
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4222

class UpdateDNSViewOutput < Struct.new(
  :id,
  :arn,
  :client_token,
  :dnssec_validation,
  :edns_client_subnet,
  :firewall_rules_fail_open,
  :name,
  :description,
  :global_resolver_id,
  :created_at,
  :updated_at,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

The unique string that identifies the request and ensures idempotency.

Returns:

  • (String)


4222
4223
4224
4225
4226
4227
4228
4229
4230
4231
4232
4233
4234
4235
4236
4237
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4222

class UpdateDNSViewOutput < Struct.new(
  :id,
  :arn,
  :client_token,
  :dnssec_validation,
  :edns_client_subnet,
  :firewall_rules_fail_open,
  :name,
  :description,
  :global_resolver_id,
  :created_at,
  :updated_at,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time when the DNS view was originally created.

Returns:

  • (Time)


4222
4223
4224
4225
4226
4227
4228
4229
4230
4231
4232
4233
4234
4235
4236
4237
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4222

class UpdateDNSViewOutput < Struct.new(
  :id,
  :arn,
  :client_token,
  :dnssec_validation,
  :edns_client_subnet,
  :firewall_rules_fail_open,
  :name,
  :description,
  :global_resolver_id,
  :created_at,
  :updated_at,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the updated DNS view.

Returns:

  • (String)


4222
4223
4224
4225
4226
4227
4228
4229
4230
4231
4232
4233
4234
4235
4236
4237
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4222

class UpdateDNSViewOutput < Struct.new(
  :id,
  :arn,
  :client_token,
  :dnssec_validation,
  :edns_client_subnet,
  :firewall_rules_fail_open,
  :name,
  :description,
  :global_resolver_id,
  :created_at,
  :updated_at,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#dnssec_validationString

Whether DNSSEC validation is enabled for the updated DNS view.

Returns:

  • (String)


4222
4223
4224
4225
4226
4227
4228
4229
4230
4231
4232
4233
4234
4235
4236
4237
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4222

class UpdateDNSViewOutput < Struct.new(
  :id,
  :arn,
  :client_token,
  :dnssec_validation,
  :edns_client_subnet,
  :firewall_rules_fail_open,
  :name,
  :description,
  :global_resolver_id,
  :created_at,
  :updated_at,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#edns_client_subnetString

Whether EDNS Client Subnet injection is enabled for the updated DNS view.

Returns:

  • (String)


4222
4223
4224
4225
4226
4227
4228
4229
4230
4231
4232
4233
4234
4235
4236
4237
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4222

class UpdateDNSViewOutput < Struct.new(
  :id,
  :arn,
  :client_token,
  :dnssec_validation,
  :edns_client_subnet,
  :firewall_rules_fail_open,
  :name,
  :description,
  :global_resolver_id,
  :created_at,
  :updated_at,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#firewall_rules_fail_openString

Whether firewall rules fail open when they cannot be evaluated for the updated DNS view.

Returns:

  • (String)


4222
4223
4224
4225
4226
4227
4228
4229
4230
4231
4232
4233
4234
4235
4236
4237
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4222

class UpdateDNSViewOutput < Struct.new(
  :id,
  :arn,
  :client_token,
  :dnssec_validation,
  :edns_client_subnet,
  :firewall_rules_fail_open,
  :name,
  :description,
  :global_resolver_id,
  :created_at,
  :updated_at,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#global_resolver_idString

The ID of the global resolver associated with the updated DNS view.

Returns:

  • (String)


4222
4223
4224
4225
4226
4227
4228
4229
4230
4231
4232
4233
4234
4235
4236
4237
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4222

class UpdateDNSViewOutput < Struct.new(
  :id,
  :arn,
  :client_token,
  :dnssec_validation,
  :edns_client_subnet,
  :firewall_rules_fail_open,
  :name,
  :description,
  :global_resolver_id,
  :created_at,
  :updated_at,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The unique identifier of the updated DNS view.

Returns:

  • (String)


4222
4223
4224
4225
4226
4227
4228
4229
4230
4231
4232
4233
4234
4235
4236
4237
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4222

class UpdateDNSViewOutput < Struct.new(
  :id,
  :arn,
  :client_token,
  :dnssec_validation,
  :edns_client_subnet,
  :firewall_rules_fail_open,
  :name,
  :description,
  :global_resolver_id,
  :created_at,
  :updated_at,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the updated DNS view.

Returns:

  • (String)


4222
4223
4224
4225
4226
4227
4228
4229
4230
4231
4232
4233
4234
4235
4236
4237
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4222

class UpdateDNSViewOutput < Struct.new(
  :id,
  :arn,
  :client_token,
  :dnssec_validation,
  :edns_client_subnet,
  :firewall_rules_fail_open,
  :name,
  :description,
  :global_resolver_id,
  :created_at,
  :updated_at,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the updated DNS view.

Returns:

  • (String)


4222
4223
4224
4225
4226
4227
4228
4229
4230
4231
4232
4233
4234
4235
4236
4237
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4222

class UpdateDNSViewOutput < Struct.new(
  :id,
  :arn,
  :client_token,
  :dnssec_validation,
  :edns_client_subnet,
  :firewall_rules_fail_open,
  :name,
  :description,
  :global_resolver_id,
  :created_at,
  :updated_at,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The date and time when the DNS view was last updated.

Returns:

  • (Time)


4222
4223
4224
4225
4226
4227
4228
4229
4230
4231
4232
4233
4234
4235
4236
4237
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4222

class UpdateDNSViewOutput < Struct.new(
  :id,
  :arn,
  :client_token,
  :dnssec_validation,
  :edns_client_subnet,
  :firewall_rules_fail_open,
  :name,
  :description,
  :global_resolver_id,
  :created_at,
  :updated_at,
  :status)
  SENSITIVE = []
  include Aws::Structure
end