Class: Aws::Route53GlobalResolver::Types::UpdateFirewallRuleInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53GlobalResolver::Types::UpdateFirewallRuleInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53globalresolver/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action ⇒ String
The action that DNS Firewall should take on a DNS query when it matches one of the domains in the rule's domain list, or a threat in a DNS Firewall Advanced rule.
-
#block_override_dns_type ⇒ String
The DNS record's type.
-
#block_override_domain ⇒ String
The custom DNS record to send back in response to the query.
-
#block_override_ttl ⇒ Integer
The recommended amount of time, in seconds, for the DNS resolver or web browser to cache the provided override record.
-
#block_response ⇒ String
The way that you want DNS Firewall to block the request.
-
#client_token ⇒ String
A unique, case-sensitive identifier to ensure idempotency.
-
#confidence_threshold ⇒ String
The confidence threshold for DNS Firewall Advanced.
-
#description ⇒ String
The description for the Firewall rule.
-
#dns_advanced_protection ⇒ String
The type of the DNS Firewall Advanced rule.
-
#firewall_rule_id ⇒ String
The ID of the DNS Firewall rule.
-
#name ⇒ String
The name of the DNS Firewall rule.
-
#priority ⇒ Integer
The setting that determines the processing order of the rule in the rule group.
Instance Attribute Details
#action ⇒ String
The action that DNS Firewall should take on a DNS query when it matches one of the domains in the rule's domain list, or a threat in a DNS Firewall Advanced rule.
4353 4354 4355 4356 4357 4358 4359 4360 4361 4362 4363 4364 4365 4366 4367 4368 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4353 class UpdateFirewallRuleInput < Struct.new( :action, :block_override_dns_type, :block_override_domain, :block_override_ttl, :block_response, :client_token, :confidence_threshold, :description, :dns_advanced_protection, :firewall_rule_id, :name, :priority) SENSITIVE = [] include Aws::Structure end |
#block_override_dns_type ⇒ String
The DNS record's type. This determines the format of the record
value that you provided in BlockOverrideDomain. Used for the rule
action BLOCK with a BlockResponse setting of OVERRIDE.
4353 4354 4355 4356 4357 4358 4359 4360 4361 4362 4363 4364 4365 4366 4367 4368 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4353 class UpdateFirewallRuleInput < Struct.new( :action, :block_override_dns_type, :block_override_domain, :block_override_ttl, :block_response, :client_token, :confidence_threshold, :description, :dns_advanced_protection, :firewall_rule_id, :name, :priority) SENSITIVE = [] include Aws::Structure end |
#block_override_domain ⇒ String
The custom DNS record to send back in response to the query. Used
for the rule action BLOCK with a BlockResponse setting of
OVERRIDE.
4353 4354 4355 4356 4357 4358 4359 4360 4361 4362 4363 4364 4365 4366 4367 4368 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4353 class UpdateFirewallRuleInput < Struct.new( :action, :block_override_dns_type, :block_override_domain, :block_override_ttl, :block_response, :client_token, :confidence_threshold, :description, :dns_advanced_protection, :firewall_rule_id, :name, :priority) SENSITIVE = [] include Aws::Structure end |
#block_override_ttl ⇒ Integer
The recommended amount of time, in seconds, for the DNS resolver or
web browser to cache the provided override record. Used for the rule
action BLOCK with a BlockResponse setting of OVERRIDE.
4353 4354 4355 4356 4357 4358 4359 4360 4361 4362 4363 4364 4365 4366 4367 4368 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4353 class UpdateFirewallRuleInput < Struct.new( :action, :block_override_dns_type, :block_override_domain, :block_override_ttl, :block_response, :client_token, :confidence_threshold, :description, :dns_advanced_protection, :firewall_rule_id, :name, :priority) SENSITIVE = [] include Aws::Structure end |
#block_response ⇒ String
The way that you want DNS Firewall to block the request. Used for
the rule action setting BLOCK.
4353 4354 4355 4356 4357 4358 4359 4360 4361 4362 4363 4364 4365 4366 4367 4368 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4353 class UpdateFirewallRuleInput < Struct.new( :action, :block_override_dns_type, :block_override_domain, :block_override_ttl, :block_response, :client_token, :confidence_threshold, :description, :dns_advanced_protection, :firewall_rule_id, :name, :priority) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier to ensure idempotency. This
means that making the same request multiple times with the same
clientToken has the same result every time.
A suitable default value is auto-generated. You should normally not need to pass this option.
4353 4354 4355 4356 4357 4358 4359 4360 4361 4362 4363 4364 4365 4366 4367 4368 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4353 class UpdateFirewallRuleInput < Struct.new( :action, :block_override_dns_type, :block_override_domain, :block_override_ttl, :block_response, :client_token, :confidence_threshold, :description, :dns_advanced_protection, :firewall_rule_id, :name, :priority) SENSITIVE = [] include Aws::Structure end |
#confidence_threshold ⇒ String
The confidence threshold for DNS Firewall Advanced. You must provide this value when you create a DNS Firewall Advanced rule.
4353 4354 4355 4356 4357 4358 4359 4360 4361 4362 4363 4364 4365 4366 4367 4368 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4353 class UpdateFirewallRuleInput < Struct.new( :action, :block_override_dns_type, :block_override_domain, :block_override_ttl, :block_response, :client_token, :confidence_threshold, :description, :dns_advanced_protection, :firewall_rule_id, :name, :priority) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description for the Firewall rule.
4353 4354 4355 4356 4357 4358 4359 4360 4361 4362 4363 4364 4365 4366 4367 4368 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4353 class UpdateFirewallRuleInput < Struct.new( :action, :block_override_dns_type, :block_override_domain, :block_override_ttl, :block_response, :client_token, :confidence_threshold, :description, :dns_advanced_protection, :firewall_rule_id, :name, :priority) SENSITIVE = [] include Aws::Structure end |
#dns_advanced_protection ⇒ String
The type of the DNS Firewall Advanced rule. Valid values are DGA, DNS_TUNNELING, and DICTIONARY_DGA.
4353 4354 4355 4356 4357 4358 4359 4360 4361 4362 4363 4364 4365 4366 4367 4368 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4353 class UpdateFirewallRuleInput < Struct.new( :action, :block_override_dns_type, :block_override_domain, :block_override_ttl, :block_response, :client_token, :confidence_threshold, :description, :dns_advanced_protection, :firewall_rule_id, :name, :priority) SENSITIVE = [] include Aws::Structure end |
#firewall_rule_id ⇒ String
The ID of the DNS Firewall rule.
4353 4354 4355 4356 4357 4358 4359 4360 4361 4362 4363 4364 4365 4366 4367 4368 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4353 class UpdateFirewallRuleInput < Struct.new( :action, :block_override_dns_type, :block_override_domain, :block_override_ttl, :block_response, :client_token, :confidence_threshold, :description, :dns_advanced_protection, :firewall_rule_id, :name, :priority) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the DNS Firewall rule.
4353 4354 4355 4356 4357 4358 4359 4360 4361 4362 4363 4364 4365 4366 4367 4368 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4353 class UpdateFirewallRuleInput < Struct.new( :action, :block_override_dns_type, :block_override_domain, :block_override_ttl, :block_response, :client_token, :confidence_threshold, :description, :dns_advanced_protection, :firewall_rule_id, :name, :priority) SENSITIVE = [] include Aws::Structure end |
#priority ⇒ Integer
The setting that determines the processing order of the rule in the rule group. DNS Firewall processes the rules in a rule group by order of priority, starting from the lowest setting.
4353 4354 4355 4356 4357 4358 4359 4360 4361 4362 4363 4364 4365 4366 4367 4368 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4353 class UpdateFirewallRuleInput < Struct.new( :action, :block_override_dns_type, :block_override_domain, :block_override_ttl, :block_response, :client_token, :confidence_threshold, :description, :dns_advanced_protection, :firewall_rule_id, :name, :priority) SENSITIVE = [] include Aws::Structure end |