Class: Aws::Route53GlobalResolver::Types::UpdateFirewallRuleOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53GlobalResolver::Types::UpdateFirewallRuleOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53globalresolver/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action ⇒ String
The action that DNS Firewall should take on a DNS query when it matches one of the domains in the rule's domain list, or a threat in a DNS Firewall Advanced rule.
-
#block_override_dns_type ⇒ String
The DNS record's type.
-
#block_override_domain ⇒ String
The custom DNS record to send back in response to the query.
-
#block_override_ttl ⇒ Integer
The recommended amount of time, in seconds, for the DNS resolver or web browser to cache the provided override record.
-
#block_response ⇒ String
The way that you want DNS Firewall to block the request.
-
#confidence_threshold ⇒ String
The confidence threshold for DNS Firewall Advanced.
-
#created_at ⇒ Time
The time and date the Firewall rule was created.
-
#description ⇒ String
The description of the Firewall rule.
-
#dns_advanced_protection ⇒ String
The type of the DNS Firewall Advanced rule.
-
#dns_view_id ⇒ String
The ID of the DNS view the Firewall rule is associated with.
-
#firewall_domain_list_id ⇒ String
The ID of the domain list associated with the Firewall rule.
-
#id ⇒ String
The ID of the Firewall rule.
-
#name ⇒ String
The name of the Firewall rule.
-
#priority ⇒ Integer
The setting that determines the processing order of the rule in the rule group.
-
#query_type ⇒ String
The DNS query type you want the rule to evaluate.
-
#status ⇒ String
The operational status of the firewall rule.
-
#updated_at ⇒ Time
The time and date the rule was updated.
Instance Attribute Details
#action ⇒ String
The action that DNS Firewall should take on a DNS query when it matches one of the domains in the rule's domain list, or a threat in a DNS Firewall Advanced rule.
4453 4454 4455 4456 4457 4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4453 class UpdateFirewallRuleOutput < Struct.new( :action, :block_override_dns_type, :block_override_domain, :block_override_ttl, :block_response, :confidence_threshold, :created_at, :description, :dns_advanced_protection, :firewall_domain_list_id, :id, :name, :priority, :dns_view_id, :query_type, :status, :updated_at) SENSITIVE = [] include Aws::Structure end |
#block_override_dns_type ⇒ String
The DNS record's type. This determines the format of the record
value that you provided in BlockOverrideDomain. Used for the rule
action BLOCK with a BlockResponse setting of OVERRIDE.
4453 4454 4455 4456 4457 4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4453 class UpdateFirewallRuleOutput < Struct.new( :action, :block_override_dns_type, :block_override_domain, :block_override_ttl, :block_response, :confidence_threshold, :created_at, :description, :dns_advanced_protection, :firewall_domain_list_id, :id, :name, :priority, :dns_view_id, :query_type, :status, :updated_at) SENSITIVE = [] include Aws::Structure end |
#block_override_domain ⇒ String
The custom DNS record to send back in response to the query. Used
for the rule action BLOCK with a BlockResponse setting of
OVERRIDE.
4453 4454 4455 4456 4457 4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4453 class UpdateFirewallRuleOutput < Struct.new( :action, :block_override_dns_type, :block_override_domain, :block_override_ttl, :block_response, :confidence_threshold, :created_at, :description, :dns_advanced_protection, :firewall_domain_list_id, :id, :name, :priority, :dns_view_id, :query_type, :status, :updated_at) SENSITIVE = [] include Aws::Structure end |
#block_override_ttl ⇒ Integer
The recommended amount of time, in seconds, for the DNS resolver or
web browser to cache the provided override record. Used for the rule
action BLOCK with a BlockResponse setting of OVERRIDE.
4453 4454 4455 4456 4457 4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4453 class UpdateFirewallRuleOutput < Struct.new( :action, :block_override_dns_type, :block_override_domain, :block_override_ttl, :block_response, :confidence_threshold, :created_at, :description, :dns_advanced_protection, :firewall_domain_list_id, :id, :name, :priority, :dns_view_id, :query_type, :status, :updated_at) SENSITIVE = [] include Aws::Structure end |
#block_response ⇒ String
The way that you want DNS Firewall to block the request. Used for
the rule action setting BLOCK.
4453 4454 4455 4456 4457 4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4453 class UpdateFirewallRuleOutput < Struct.new( :action, :block_override_dns_type, :block_override_domain, :block_override_ttl, :block_response, :confidence_threshold, :created_at, :description, :dns_advanced_protection, :firewall_domain_list_id, :id, :name, :priority, :dns_view_id, :query_type, :status, :updated_at) SENSITIVE = [] include Aws::Structure end |
#confidence_threshold ⇒ String
The confidence threshold for DNS Firewall Advanced. You must provide this value when you create a DNS Firewall Advanced rule.
4453 4454 4455 4456 4457 4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4453 class UpdateFirewallRuleOutput < Struct.new( :action, :block_override_dns_type, :block_override_domain, :block_override_ttl, :block_response, :confidence_threshold, :created_at, :description, :dns_advanced_protection, :firewall_domain_list_id, :id, :name, :priority, :dns_view_id, :query_type, :status, :updated_at) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The time and date the Firewall rule was created.
4453 4454 4455 4456 4457 4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4453 class UpdateFirewallRuleOutput < Struct.new( :action, :block_override_dns_type, :block_override_domain, :block_override_ttl, :block_response, :confidence_threshold, :created_at, :description, :dns_advanced_protection, :firewall_domain_list_id, :id, :name, :priority, :dns_view_id, :query_type, :status, :updated_at) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the Firewall rule.
4453 4454 4455 4456 4457 4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4453 class UpdateFirewallRuleOutput < Struct.new( :action, :block_override_dns_type, :block_override_domain, :block_override_ttl, :block_response, :confidence_threshold, :created_at, :description, :dns_advanced_protection, :firewall_domain_list_id, :id, :name, :priority, :dns_view_id, :query_type, :status, :updated_at) SENSITIVE = [] include Aws::Structure end |
#dns_advanced_protection ⇒ String
The type of the DNS Firewall Advanced rule. Valid values are DGA, DNS_TUNNELING, and DICTIONARY_DGA.
4453 4454 4455 4456 4457 4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4453 class UpdateFirewallRuleOutput < Struct.new( :action, :block_override_dns_type, :block_override_domain, :block_override_ttl, :block_response, :confidence_threshold, :created_at, :description, :dns_advanced_protection, :firewall_domain_list_id, :id, :name, :priority, :dns_view_id, :query_type, :status, :updated_at) SENSITIVE = [] include Aws::Structure end |
#dns_view_id ⇒ String
The ID of the DNS view the Firewall rule is associated with.
4453 4454 4455 4456 4457 4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4453 class UpdateFirewallRuleOutput < Struct.new( :action, :block_override_dns_type, :block_override_domain, :block_override_ttl, :block_response, :confidence_threshold, :created_at, :description, :dns_advanced_protection, :firewall_domain_list_id, :id, :name, :priority, :dns_view_id, :query_type, :status, :updated_at) SENSITIVE = [] include Aws::Structure end |
#firewall_domain_list_id ⇒ String
The ID of the domain list associated with the Firewall rule.
4453 4454 4455 4456 4457 4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4453 class UpdateFirewallRuleOutput < Struct.new( :action, :block_override_dns_type, :block_override_domain, :block_override_ttl, :block_response, :confidence_threshold, :created_at, :description, :dns_advanced_protection, :firewall_domain_list_id, :id, :name, :priority, :dns_view_id, :query_type, :status, :updated_at) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the Firewall rule.
4453 4454 4455 4456 4457 4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4453 class UpdateFirewallRuleOutput < Struct.new( :action, :block_override_dns_type, :block_override_domain, :block_override_ttl, :block_response, :confidence_threshold, :created_at, :description, :dns_advanced_protection, :firewall_domain_list_id, :id, :name, :priority, :dns_view_id, :query_type, :status, :updated_at) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the Firewall rule.
4453 4454 4455 4456 4457 4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4453 class UpdateFirewallRuleOutput < Struct.new( :action, :block_override_dns_type, :block_override_domain, :block_override_ttl, :block_response, :confidence_threshold, :created_at, :description, :dns_advanced_protection, :firewall_domain_list_id, :id, :name, :priority, :dns_view_id, :query_type, :status, :updated_at) SENSITIVE = [] include Aws::Structure end |
#priority ⇒ Integer
The setting that determines the processing order of the rule in the rule group. DNS Firewall processes the rules in a rule group by order of priority, starting from the lowest setting.
4453 4454 4455 4456 4457 4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4453 class UpdateFirewallRuleOutput < Struct.new( :action, :block_override_dns_type, :block_override_domain, :block_override_ttl, :block_response, :confidence_threshold, :created_at, :description, :dns_advanced_protection, :firewall_domain_list_id, :id, :name, :priority, :dns_view_id, :query_type, :status, :updated_at) SENSITIVE = [] include Aws::Structure end |
#query_type ⇒ String
The DNS query type you want the rule to evaluate.
4453 4454 4455 4456 4457 4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4453 class UpdateFirewallRuleOutput < Struct.new( :action, :block_override_dns_type, :block_override_domain, :block_override_ttl, :block_response, :confidence_threshold, :created_at, :description, :dns_advanced_protection, :firewall_domain_list_id, :id, :name, :priority, :dns_view_id, :query_type, :status, :updated_at) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The operational status of the firewall rule.
4453 4454 4455 4456 4457 4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4453 class UpdateFirewallRuleOutput < Struct.new( :action, :block_override_dns_type, :block_override_domain, :block_override_ttl, :block_response, :confidence_threshold, :created_at, :description, :dns_advanced_protection, :firewall_domain_list_id, :id, :name, :priority, :dns_view_id, :query_type, :status, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The time and date the rule was updated.
4453 4454 4455 4456 4457 4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4453 class UpdateFirewallRuleOutput < Struct.new( :action, :block_override_dns_type, :block_override_domain, :block_override_ttl, :block_response, :confidence_threshold, :created_at, :description, :dns_advanced_protection, :firewall_domain_list_id, :id, :name, :priority, :dns_view_id, :query_type, :status, :updated_at) SENSITIVE = [] include Aws::Structure end |