Class: Aws::Route53GlobalResolver::Types::UpdateGlobalResolverInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-route53globalresolver/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

The description of the Global Resolver.

Returns:

  • (String)


4386
4387
4388
4389
4390
4391
4392
4393
4394
4395
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4386

class UpdateGlobalResolverInput < Struct.new(
  :global_resolver_id,
  :name,
  :observability_region,
  :description,
  :ip_address_type,
  :regions)
  SENSITIVE = []
  include Aws::Structure
end

#global_resolver_idString

The ID of the Global Resolver.

Returns:

  • (String)


4386
4387
4388
4389
4390
4391
4392
4393
4394
4395
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4386

class UpdateGlobalResolverInput < Struct.new(
  :global_resolver_id,
  :name,
  :observability_region,
  :description,
  :ip_address_type,
  :regions)
  SENSITIVE = []
  include Aws::Structure
end

#ip_address_typeString

The IP address type for the Global Resolver. Valid values are IPV4 or DUAL_STACK for both IPv4 and IPv6 support.

Returns:

  • (String)


4386
4387
4388
4389
4390
4391
4392
4393
4394
4395
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4386

class UpdateGlobalResolverInput < Struct.new(
  :global_resolver_id,
  :name,
  :observability_region,
  :description,
  :ip_address_type,
  :regions)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the Global Resolver.

Returns:

  • (String)


4386
4387
4388
4389
4390
4391
4392
4393
4394
4395
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4386

class UpdateGlobalResolverInput < Struct.new(
  :global_resolver_id,
  :name,
  :observability_region,
  :description,
  :ip_address_type,
  :regions)
  SENSITIVE = []
  include Aws::Structure
end

#observability_regionString

The Amazon Web Services Regions in which the users’ Global Resolver query resolution logs will be propagated.

Returns:

  • (String)


4386
4387
4388
4389
4390
4391
4392
4393
4394
4395
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4386

class UpdateGlobalResolverInput < Struct.new(
  :global_resolver_id,
  :name,
  :observability_region,
  :description,
  :ip_address_type,
  :regions)
  SENSITIVE = []
  include Aws::Structure
end

#regionsArray<String>

The list of Amazon Web Services Regions where the Global Resolver will operate. The resolver will be distributed across these Regions to provide global availability and low-latency DNS resolution.

Returns:

  • (Array<String>)


4386
4387
4388
4389
4390
4391
4392
4393
4394
4395
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4386

class UpdateGlobalResolverInput < Struct.new(
  :global_resolver_id,
  :name,
  :observability_region,
  :description,
  :ip_address_type,
  :regions)
  SENSITIVE = []
  include Aws::Structure
end