Class: Aws::Route53GlobalResolver::Types::UpdateGlobalResolverOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53GlobalResolver::Types::UpdateGlobalResolverOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53globalresolver/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the Global Resolver.
-
#client_token ⇒ String
A unique, case-sensitive identifier to ensure idempotency.
-
#created_at ⇒ Time
The time and date the Global Resolverwas created.
-
#description ⇒ String
Description of the Global Resolver.
-
#dns_name ⇒ String
The hostname to be used by the customers' DNS clients for certification validation.
-
#id ⇒ String
The ID of the Global Resolver.
-
#ip_address_type ⇒ String
The IP address type configured for the updated Global Resolver.
-
#ipv4_addresses ⇒ Array<String>
List of anycast IPv4 addresses associated with the Global Resolver instance.
-
#ipv6_addresses ⇒ Array<String>
List of anycast IPv6 addresses associated with the updated Global Resolver instance.
-
#name ⇒ String
Name of the Global Resolver.
-
#observability_region ⇒ String
The Amazon Web Services Regions in which the users' Global Resolver query resolution logs will be propagated.
-
#regions ⇒ Array<String>
The Amazon Web Services Regions in which the Global Resolver will operate.
-
#status ⇒ String
The operational status of the Global Resolver.
-
#updated_at ⇒ Time
The time and date the Global Resolver was updated.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the Global Resolver.
4582 4583 4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4582 class UpdateGlobalResolverOutput < Struct.new( :id, :arn, :client_token, :dns_name, :observability_region, :name, :description, :regions, :created_at, :updated_at, :status, :ipv4_addresses, :ipv6_addresses, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier to ensure idempotency. This
means that making the same request multiple times with the same
clientToken has the same result every time.
4582 4583 4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4582 class UpdateGlobalResolverOutput < Struct.new( :id, :arn, :client_token, :dns_name, :observability_region, :name, :description, :regions, :created_at, :updated_at, :status, :ipv4_addresses, :ipv6_addresses, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The time and date the Global Resolverwas created.
4582 4583 4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4582 class UpdateGlobalResolverOutput < Struct.new( :id, :arn, :client_token, :dns_name, :observability_region, :name, :description, :regions, :created_at, :updated_at, :status, :ipv4_addresses, :ipv6_addresses, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
Description of the Global Resolver.
4582 4583 4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4582 class UpdateGlobalResolverOutput < Struct.new( :id, :arn, :client_token, :dns_name, :observability_region, :name, :description, :regions, :created_at, :updated_at, :status, :ipv4_addresses, :ipv6_addresses, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#dns_name ⇒ String
The hostname to be used by the customers' DNS clients for certification validation.
4582 4583 4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4582 class UpdateGlobalResolverOutput < Struct.new( :id, :arn, :client_token, :dns_name, :observability_region, :name, :description, :regions, :created_at, :updated_at, :status, :ipv4_addresses, :ipv6_addresses, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the Global Resolver.
4582 4583 4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4582 class UpdateGlobalResolverOutput < Struct.new( :id, :arn, :client_token, :dns_name, :observability_region, :name, :description, :regions, :created_at, :updated_at, :status, :ipv4_addresses, :ipv6_addresses, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#ip_address_type ⇒ String
The IP address type configured for the updated Global Resolver.
4582 4583 4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4582 class UpdateGlobalResolverOutput < Struct.new( :id, :arn, :client_token, :dns_name, :observability_region, :name, :description, :regions, :created_at, :updated_at, :status, :ipv4_addresses, :ipv6_addresses, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#ipv4_addresses ⇒ Array<String>
List of anycast IPv4 addresses associated with the Global Resolver instance.
4582 4583 4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4582 class UpdateGlobalResolverOutput < Struct.new( :id, :arn, :client_token, :dns_name, :observability_region, :name, :description, :regions, :created_at, :updated_at, :status, :ipv4_addresses, :ipv6_addresses, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#ipv6_addresses ⇒ Array<String>
List of anycast IPv6 addresses associated with the updated Global Resolver instance. This field is only populated when ipAddressType is DUAL_STACK.
4582 4583 4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4582 class UpdateGlobalResolverOutput < Struct.new( :id, :arn, :client_token, :dns_name, :observability_region, :name, :description, :regions, :created_at, :updated_at, :status, :ipv4_addresses, :ipv6_addresses, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Name of the Global Resolver.
4582 4583 4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4582 class UpdateGlobalResolverOutput < Struct.new( :id, :arn, :client_token, :dns_name, :observability_region, :name, :description, :regions, :created_at, :updated_at, :status, :ipv4_addresses, :ipv6_addresses, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#observability_region ⇒ String
The Amazon Web Services Regions in which the users' Global Resolver query resolution logs will be propagated.
4582 4583 4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4582 class UpdateGlobalResolverOutput < Struct.new( :id, :arn, :client_token, :dns_name, :observability_region, :name, :description, :regions, :created_at, :updated_at, :status, :ipv4_addresses, :ipv6_addresses, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#regions ⇒ Array<String>
The Amazon Web Services Regions in which the Global Resolver will operate.
4582 4583 4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4582 class UpdateGlobalResolverOutput < Struct.new( :id, :arn, :client_token, :dns_name, :observability_region, :name, :description, :regions, :created_at, :updated_at, :status, :ipv4_addresses, :ipv6_addresses, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The operational status of the Global Resolver.
4582 4583 4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4582 class UpdateGlobalResolverOutput < Struct.new( :id, :arn, :client_token, :dns_name, :observability_region, :name, :description, :regions, :created_at, :updated_at, :status, :ipv4_addresses, :ipv6_addresses, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The time and date the Global Resolver was updated.
4582 4583 4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4582 class UpdateGlobalResolverOutput < Struct.new( :id, :arn, :client_token, :dns_name, :observability_region, :name, :description, :regions, :created_at, :updated_at, :status, :ipv4_addresses, :ipv6_addresses, :ip_address_type) SENSITIVE = [] include Aws::Structure end |