Class: Aws::Route53GlobalResolver::Types::UpdateHostedZoneAssociationInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53GlobalResolver::Types::UpdateHostedZoneAssociationInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53globalresolver/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#hosted_zone_association_id ⇒ String
The ID of the private hosted zone association.
-
#name ⇒ String
The name you want to update the hosted zone association to.
Instance Attribute Details
#hosted_zone_association_id ⇒ String
The ID of the private hosted zone association.
4492 4493 4494 4495 4496 4497 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4492 class UpdateHostedZoneAssociationInput < Struct.new( :hosted_zone_association_id, :name) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name you want to update the hosted zone association to.
4492 4493 4494 4495 4496 4497 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4492 class UpdateHostedZoneAssociationInput < Struct.new( :hosted_zone_association_id, :name) SENSITIVE = [] include Aws::Structure end |