Class: Aws::Route53GlobalResolver::Types::UpdateDNSViewOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53GlobalResolver::Types::UpdateDNSViewOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53globalresolver/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the updated DNS view.
-
#client_token ⇒ String
The unique string that identifies the request and ensures idempotency.
-
#created_at ⇒ Time
The date and time when the DNS view was originally created.
-
#description ⇒ String
The description of the updated DNS view.
-
#dnssec_validation ⇒ String
Whether DNSSEC validation is enabled for the updated DNS view.
-
#edns_client_subnet ⇒ String
Whether EDNS Client Subnet injection is enabled for the updated DNS view.
-
#firewall_rules_fail_open ⇒ String
Whether firewall rules fail open when they cannot be evaluated for the updated DNS view.
-
#global_resolver_id ⇒ String
The ID of the global resolver associated with the updated DNS view.
-
#id ⇒ String
The unique identifier of the updated DNS view.
-
#name ⇒ String
The name of the updated DNS view.
-
#status ⇒ String
The current status of the updated DNS view.
-
#updated_at ⇒ Time
The date and time when the DNS view was last updated.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the updated DNS view.
4222 4223 4224 4225 4226 4227 4228 4229 4230 4231 4232 4233 4234 4235 4236 4237 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4222 class UpdateDNSViewOutput < Struct.new( :id, :arn, :client_token, :dnssec_validation, :edns_client_subnet, :firewall_rules_fail_open, :name, :description, :global_resolver_id, :created_at, :updated_at, :status) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
The unique string that identifies the request and ensures idempotency.
4222 4223 4224 4225 4226 4227 4228 4229 4230 4231 4232 4233 4234 4235 4236 4237 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4222 class UpdateDNSViewOutput < Struct.new( :id, :arn, :client_token, :dnssec_validation, :edns_client_subnet, :firewall_rules_fail_open, :name, :description, :global_resolver_id, :created_at, :updated_at, :status) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time when the DNS view was originally created.
4222 4223 4224 4225 4226 4227 4228 4229 4230 4231 4232 4233 4234 4235 4236 4237 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4222 class UpdateDNSViewOutput < Struct.new( :id, :arn, :client_token, :dnssec_validation, :edns_client_subnet, :firewall_rules_fail_open, :name, :description, :global_resolver_id, :created_at, :updated_at, :status) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the updated DNS view.
4222 4223 4224 4225 4226 4227 4228 4229 4230 4231 4232 4233 4234 4235 4236 4237 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4222 class UpdateDNSViewOutput < Struct.new( :id, :arn, :client_token, :dnssec_validation, :edns_client_subnet, :firewall_rules_fail_open, :name, :description, :global_resolver_id, :created_at, :updated_at, :status) SENSITIVE = [] include Aws::Structure end |
#dnssec_validation ⇒ String
Whether DNSSEC validation is enabled for the updated DNS view.
4222 4223 4224 4225 4226 4227 4228 4229 4230 4231 4232 4233 4234 4235 4236 4237 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4222 class UpdateDNSViewOutput < Struct.new( :id, :arn, :client_token, :dnssec_validation, :edns_client_subnet, :firewall_rules_fail_open, :name, :description, :global_resolver_id, :created_at, :updated_at, :status) SENSITIVE = [] include Aws::Structure end |
#edns_client_subnet ⇒ String
Whether EDNS Client Subnet injection is enabled for the updated DNS view.
4222 4223 4224 4225 4226 4227 4228 4229 4230 4231 4232 4233 4234 4235 4236 4237 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4222 class UpdateDNSViewOutput < Struct.new( :id, :arn, :client_token, :dnssec_validation, :edns_client_subnet, :firewall_rules_fail_open, :name, :description, :global_resolver_id, :created_at, :updated_at, :status) SENSITIVE = [] include Aws::Structure end |
#firewall_rules_fail_open ⇒ String
Whether firewall rules fail open when they cannot be evaluated for the updated DNS view.
4222 4223 4224 4225 4226 4227 4228 4229 4230 4231 4232 4233 4234 4235 4236 4237 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4222 class UpdateDNSViewOutput < Struct.new( :id, :arn, :client_token, :dnssec_validation, :edns_client_subnet, :firewall_rules_fail_open, :name, :description, :global_resolver_id, :created_at, :updated_at, :status) SENSITIVE = [] include Aws::Structure end |
#global_resolver_id ⇒ String
The ID of the global resolver associated with the updated DNS view.
4222 4223 4224 4225 4226 4227 4228 4229 4230 4231 4232 4233 4234 4235 4236 4237 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4222 class UpdateDNSViewOutput < Struct.new( :id, :arn, :client_token, :dnssec_validation, :edns_client_subnet, :firewall_rules_fail_open, :name, :description, :global_resolver_id, :created_at, :updated_at, :status) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique identifier of the updated DNS view.
4222 4223 4224 4225 4226 4227 4228 4229 4230 4231 4232 4233 4234 4235 4236 4237 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4222 class UpdateDNSViewOutput < Struct.new( :id, :arn, :client_token, :dnssec_validation, :edns_client_subnet, :firewall_rules_fail_open, :name, :description, :global_resolver_id, :created_at, :updated_at, :status) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the updated DNS view.
4222 4223 4224 4225 4226 4227 4228 4229 4230 4231 4232 4233 4234 4235 4236 4237 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4222 class UpdateDNSViewOutput < Struct.new( :id, :arn, :client_token, :dnssec_validation, :edns_client_subnet, :firewall_rules_fail_open, :name, :description, :global_resolver_id, :created_at, :updated_at, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the updated DNS view.
4222 4223 4224 4225 4226 4227 4228 4229 4230 4231 4232 4233 4234 4235 4236 4237 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4222 class UpdateDNSViewOutput < Struct.new( :id, :arn, :client_token, :dnssec_validation, :edns_client_subnet, :firewall_rules_fail_open, :name, :description, :global_resolver_id, :created_at, :updated_at, :status) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time when the DNS view was last updated.
4222 4223 4224 4225 4226 4227 4228 4229 4230 4231 4232 4233 4234 4235 4236 4237 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4222 class UpdateDNSViewOutput < Struct.new( :id, :arn, :client_token, :dnssec_validation, :edns_client_subnet, :firewall_rules_fail_open, :name, :description, :global_resolver_id, :created_at, :updated_at, :status) SENSITIVE = [] include Aws::Structure end |