Class: Aws::Route53GlobalResolver::Types::UpdateGlobalResolverInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53GlobalResolver::Types::UpdateGlobalResolverInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53globalresolver/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The description of the Global Resolver.
-
#global_resolver_id ⇒ String
The ID of the Global Resolver.
-
#ip_address_type ⇒ String
The IP address type for the Global Resolver.
-
#name ⇒ String
The name of the Global Resolver.
-
#observability_region ⇒ String
The Amazon Web Services Regions in which the users’ Global Resolver query resolution logs will be propagated.
-
#regions ⇒ Array<String>
The list of Amazon Web Services Regions where the Global Resolver will operate.
Instance Attribute Details
#description ⇒ String
The description of the Global Resolver.
4386 4387 4388 4389 4390 4391 4392 4393 4394 4395 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4386 class UpdateGlobalResolverInput < Struct.new( :global_resolver_id, :name, :observability_region, :description, :ip_address_type, :regions) SENSITIVE = [] include Aws::Structure end |
#global_resolver_id ⇒ String
The ID of the Global Resolver.
4386 4387 4388 4389 4390 4391 4392 4393 4394 4395 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4386 class UpdateGlobalResolverInput < Struct.new( :global_resolver_id, :name, :observability_region, :description, :ip_address_type, :regions) SENSITIVE = [] include Aws::Structure end |
#ip_address_type ⇒ String
The IP address type for the Global Resolver. Valid values are IPV4 or DUAL_STACK for both IPv4 and IPv6 support.
4386 4387 4388 4389 4390 4391 4392 4393 4394 4395 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4386 class UpdateGlobalResolverInput < Struct.new( :global_resolver_id, :name, :observability_region, :description, :ip_address_type, :regions) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the Global Resolver.
4386 4387 4388 4389 4390 4391 4392 4393 4394 4395 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4386 class UpdateGlobalResolverInput < Struct.new( :global_resolver_id, :name, :observability_region, :description, :ip_address_type, :regions) SENSITIVE = [] include Aws::Structure end |
#observability_region ⇒ String
The Amazon Web Services Regions in which the users’ Global Resolver query resolution logs will be propagated.
4386 4387 4388 4389 4390 4391 4392 4393 4394 4395 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4386 class UpdateGlobalResolverInput < Struct.new( :global_resolver_id, :name, :observability_region, :description, :ip_address_type, :regions) SENSITIVE = [] include Aws::Structure end |
#regions ⇒ Array<String>
The list of Amazon Web Services Regions where the Global Resolver will operate. The resolver will be distributed across these Regions to provide global availability and low-latency DNS resolution.
4386 4387 4388 4389 4390 4391 4392 4393 4394 4395 |
# File 'lib/aws-sdk-route53globalresolver/types.rb', line 4386 class UpdateGlobalResolverInput < Struct.new( :global_resolver_id, :name, :observability_region, :description, :ip_address_type, :regions) SENSITIVE = [] include Aws::Structure end |